@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import ListGroupResourcesPaginator, ListGroupsPaginator, SearchResourcesPaginator
 from .type_defs import (
@@ -68,18 +68,25 @@ class Exceptions:
     UnauthorizedException: Type[BotocoreClientError]
 
 
-class ResourceGroupsClient:
+class ResourceGroupsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ResourceGroupsClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#can_paginate)
         """
 
@@ -93,13 +100,17 @@ class ResourceGroupsClient:
         Configuration: List["GroupConfigurationItemTypeDef"] = None
     ) -> CreateGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
+        Creates a resource group with the specified name and description.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.create_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#create_group)
         """
 
     def delete_group(self, *, GroupName: str = None, Group: str = None) -> DeleteGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
+        Deletes the specified resource group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.delete_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#delete_group)
         """
 
@@ -111,19 +122,25 @@ class ResourceGroupsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#generate_presigned_url)
         """
 
     def get_group(self, *, GroupName: str = None, Group: str = None) -> GetGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
+        Returns information about a specified resource group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.get_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group)
         """
 
     def get_group_configuration(self, *, Group: str = None) -> GetGroupConfigurationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
+        Returns the service configuration associated with the specified resource group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group_configuration)
         """
 
@@ -131,13 +148,18 @@ class ResourceGroupsClient:
         self, *, GroupName: str = None, Group: str = None
     ) -> GetGroupQueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
+        Retrieves the resource query associated with the specified resource group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.get_group_query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_group_query)
         """
 
     def get_tags(self, *, Arn: str) -> GetTagsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
+        Returns a list of tags that are associated with a resource group, specified by
+        an ARN.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#get_tags)
         """
 
@@ -145,7 +167,9 @@ class ResourceGroupsClient:
         self, *, Group: str, ResourceArns: List[str]
     ) -> GroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
+        Adds the specified resources to the specified group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.group_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#group_resources)
         """
 
@@ -154,24 +178,29 @@ class ResourceGroupsClient:
         *,
         GroupName: str = None,
         Group: str = None,
-        Filters: List[ResourceFilterTypeDef] = None,
+        Filters: List["ResourceFilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> ListGroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
+        Returns a list of ARNs of the resources that are members of a specified resource
+        group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.list_group_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#list_group_resources)
         """
 
     def list_groups(
         self,
         *,
-        Filters: List[GroupFilterTypeDef] = None,
+        Filters: List["GroupFilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> ListGroupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
+        Returns a list of existing resource groups in your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#list_groups)
         """
 
@@ -179,7 +208,9 @@ class ResourceGroupsClient:
         self, *, Group: str = None, Configuration: List["GroupConfigurationItemTypeDef"] = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
+        Attaches a service configuration to the specified group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.put_group_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#put_group_configuration)
         """
 
@@ -191,13 +222,17 @@ class ResourceGroupsClient:
         NextToken: str = None
     ) -> SearchResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
+        Returns a list of AWS resource identifiers that matches the specified query.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#search_resources)
         """
 
     def tag(self, *, Arn: str, Tags: Dict[str, str]) -> TagOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.tag)
+        Adds tags to a resource group with the specified ARN.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.tag)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#tag)
         """
 
@@ -205,13 +240,17 @@ class ResourceGroupsClient:
         self, *, Group: str, ResourceArns: List[str]
     ) -> UngroupResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
+        Removes the specified resources from the specified group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.ungroup_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#ungroup_resources)
         """
 
     def untag(self, *, Arn: str, Keys: List[str]) -> UntagOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.untag)
+        Deletes tags from a specified resource group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.untag)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#untag)
         """
 
@@ -219,7 +258,9 @@ class ResourceGroupsClient:
         self, *, GroupName: str = None, Group: str = None, Description: str = None
     ) -> UpdateGroupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
+        Updates the description for an existing group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.update_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#update_group)
         """
 
@@ -227,7 +268,9 @@ class ResourceGroupsClient:
         self, *, ResourceQuery: "ResourceQueryTypeDef", GroupName: str = None, Group: str = None
     ) -> UpdateGroupQueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
+        Updates the resource query of a group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Client.update_group_query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client.html#update_group_query)
         """
 
@@ -236,13 +279,15 @@ class ResourceGroupsClient:
         self, operation_name: Literal["list_group_resources"]
     ) -> ListGroupResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupresourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_groups"]) -> ListGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#listgroupspaginator)
         """
 
     @overload
@@ -250,5 +295,6 @@ class ResourceGroupsClient:
         self, operation_name: Literal["search_resources"]
     ) -> SearchResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#searchresourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/paginators.html#searchresourcespaginator)
         """
